pub struct CitationWebSearchResultLocation {
pub cited_text: String,
pub encrypted_index: String,
pub title: Option<String>,
pub url: String,
}Expand description
Represents a web search result location citation.
This type is used to specify a citation that references web search results.
Fields
cited_text: StringThe text that was cited
encrypted_index: StringAn encrypted identifier for the web search result
title: Option<String>Optional title of the web page
url: StringThe URL of the web page containing the cited content
Implementations