pub struct ToolTextEditor20250124 {
pub name: String,
pub cache_control: Option<CacheControlEphemeral>,
}Expand description
Parameters for the Text Editor tool type, version 20250124.
This tool allows the AI to perform text editing operations via the API.
Fields
name: StringName of the tool. This is how the tool will be called by the model and in tool_use blocks.
Always set to “str_replace_editor”.
cache_control: Option<CacheControlEphemeral>Create a cache control breakpoint at this content block. If provided, this instructs the API to not cache this tool or its results.
Implementations
Sourceimpl ToolTextEditor20250124
impl ToolTextEditor20250124
Sourcepub fn with_ephemeral_cache_control(self) -> Self
pub fn with_ephemeral_cache_control(self) -> Self
Sets the cache control to ephemeral for this tool.