pub struct ToolUseBlock {
pub id: String,
pub input: Value,
pub name: String,
pub cache_control: Option<CacheControlEphemeral>,
}Expand description
A block representing a tool use request from the model.
ToolUseBlocks indicate the model wants to use a specific tool with certain inputs.
Fields
id: StringA unique identifier for this tool use request.
input: ValueThe input data for the tool, can be any valid JSON.
name: StringThe name of the tool being invoked.
cache_control: Option<CacheControlEphemeral>Create a cache control breakpoint at this content block.
Implementations
Sourceimpl ToolUseBlock
impl ToolUseBlock
Sourcepub fn new<S1: Into<String>, S2: Into<String>>(
id: S1,
name: S2,
input: Value,
) -> Self
pub fn new<S1: Into<String>, S2: Into<String>>( id: S1, name: S2, input: Value, ) -> Self
Creates a new ToolUseBlock with the specified id, name, and input.
Sourcepub fn with_cache_control(self, cache_control: CacheControlEphemeral) -> Self
pub fn with_cache_control(self, cache_control: CacheControlEphemeral) -> Self
Add a cache control to this tool use block.