pub struct WebSearchToolResultBlock {
pub content: WebSearchToolResultBlockContent,
pub tool_use_id: String,
pub cache_control: Option<CacheControlEphemeral>,
}Expand description
A block containing the results of a web search tool operation.
WebSearchToolResultBlock contains either a list of search results or an error.
Fields
content: WebSearchToolResultBlockContentThe content of the web search tool result.
tool_use_id: StringThe ID of the tool use that this result is for.
cache_control: Option<CacheControlEphemeral>Create a cache control breakpoint at this content block.
Implementations
Sourceimpl WebSearchToolResultBlock
impl WebSearchToolResultBlock
Sourcepub fn new<S: Into<String>>(
content: WebSearchToolResultBlockContent,
tool_use_id: S,
) -> Self
pub fn new<S: Into<String>>( content: WebSearchToolResultBlockContent, tool_use_id: S, ) -> Self
Creates a new WebSearchToolResultBlock.
Sourcepub fn new_with_results<S: Into<String>>(
results: Vec<WebSearchResultBlock>,
tool_use_id: S,
) -> Self
pub fn new_with_results<S: Into<String>>( results: Vec<WebSearchResultBlock>, tool_use_id: S, ) -> Self
Creates a new WebSearchToolResultBlock with results.
Sourcepub fn new_with_error<S: Into<String>>(
error: WebSearchToolResultError,
tool_use_id: S,
) -> Self
pub fn new_with_error<S: Into<String>>( error: WebSearchToolResultError, tool_use_id: S, ) -> Self
Creates a new WebSearchToolResultBlock with an error.
Sourcepub fn with_cache_control(self, cache_control: CacheControlEphemeral) -> Self
pub fn with_cache_control(self, cache_control: CacheControlEphemeral) -> Self
Add a cache control to this web search tool result block.
Sourcepub fn has_results(&self) -> bool
pub fn has_results(&self) -> bool
Returns true if the web search result contains successful results.
Sourcepub fn result_count(&self) -> usize
pub fn result_count(&self) -> usize
Returns the number of search results, or 0 if this is an error result.