pub struct PlainTextRenderer { /* private fields */ }Expand description
Plain text renderer with optional ANSI styling.
This renderer outputs text directly to stdout with optional ANSI escape codes for styling thinking blocks and tool use.
Implementations
Sourceimpl PlainTextRenderer
impl PlainTextRenderer
Sourcepub fn with_color(use_color: bool) -> Self
pub fn with_color(use_color: bool) -> Self
Creates a new PlainTextRenderer with specified color setting.
Sourcepub fn with_interrupt(self, interrupted: Arc<AtomicBool>) -> Self
pub fn with_interrupt(self, interrupted: Arc<AtomicBool>) -> Self
Attaches an interrupt flag to the renderer.
Sourcepub fn with_color_and_interrupt(
use_color: bool,
interrupted: Arc<AtomicBool>,
) -> Self
pub fn with_color_and_interrupt( use_color: bool, interrupted: Arc<AtomicBool>, ) -> Self
Creates a new PlainTextRenderer with specified color and interrupt flag.