pub struct ToolTextEditor20250728 {
pub name: String,
pub cache_control: Option<CacheControlEphemeral>,
pub max_characters: Option<i32>,
}Expand description
Parameters for the Text Editor tool type, version 20250728.
This tool allows the AI to perform text editing operations via the API.
Fields
name: StringName of the tool. This is how the tool will be called by the model and in tool_use blocks.
Always set to “str_replace_based_edit_tool”.
cache_control: Option<CacheControlEphemeral>Create a cache control breakpoint at this content block. If provided, this instructs the API to not cache this tool or its results.
max_characters: Option<i32>Maximum characters to display when viewing a file. If not specified, defaults to showing the full file.
Implementations
Sourceimpl ToolTextEditor20250728
impl ToolTextEditor20250728
Sourcepub fn with_ephemeral_cache_control(self) -> Self
pub fn with_ephemeral_cache_control(self) -> Self
Sets the cache control to ephemeral for this tool.
Sourcepub fn with_max_characters(self, max_characters: i32) -> Self
pub fn with_max_characters(self, max_characters: i32) -> Self
Sets the maximum characters to display when viewing a file.